@@ -6,12 +6,12 @@ import numpy as np
 import json
 import traceback
 import sys
-from .src.cusFuns.core.FunsPool import auto_register
-from .src.core.Versions import VersionManager
+from src.cusFuns.core.FunsPool import auto_register
+from src.core.Versions import VersionManager
 
-from .src.helper.utils import json_converter
-from .src.dataModel.pandasCmd import PandasCmd
-from .src.core.Proxy import ProxyManager
+from src.helper.utils import json_converter
+from src.dataModel.pandasCmd import PandasCmd
+from src.core.Proxy import ProxyManager
 
 import webbrowser
 import os
@@ -212,7 +212,7 @@ def run():
         vm = VersionManager()
         if vm.has_updated():
             print('发现新版本，开始更新')
-            vm.update()
+            vm.start_update()
             print('更新完成')
 
         webbrowser.open_new(f'http://localhost:{port}/')
