@@ -8,7 +8,7 @@ class VersionManager(object):
 
     # m_pkg_name = 'pandas-coder'
     m_pkg_name = 'pdcoder'
-    m_current_version = tuple('0.2.0'.split('.'))
+    m_current_version = tuple('0.3.1'.split('.'))
     m_version_re = re.compile(r'\((from versions: (.*?))\)')
 
     def has_updated(self) -> bool:
@@ -26,11 +26,19 @@ class VersionManager(object):
         last = self.get_versions()[-1]
         return last
 
-    def update(self):
-        self._use_pip(['install', self.m_pkg_name, '-U'])
+    def start_update(self):
+        import sys
+        import os
+        os.system(
+            'start pip install pdcoder -U  && python main.py && echo done;pause')
+        # subprocess.Popen(
+        #     'pip install pdcoder -U  && python main.py && echo done', shell=True)
+        sys.exit(1)
+        # self._use_pip(['install', self.m_pkg_name, '-U'])
 
     def _use_pip(self, cmds: List[str]):
-        cmds = ['pip'] + cmds + ['-i', 'https://pypi.douban.com/simple/']
+        # cmds = ['pip'] + cmds + ['-i', 'https://pypi.douban.com/simple/']
+        cmds = ['pip'] + cmds
 
         return subprocess.run(cmds,
                               stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
